import { SearchSelect } from "./ak-search-select.js";

export { SearchSelect };
export default SearchSelect;
